summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorenge <enge@211d60ee-9f03-0410-a15a-8952a2c7a4e4>2012-07-05 08:55:42 +0000
committerenge <enge@211d60ee-9f03-0410-a15a-8952a2c7a4e4>2012-07-05 08:55:42 +0000
commiteb4484e39772db743d5ae49e0fe322ef3fcdb9db (patch)
tree55afe6dd4fc27feac975d138a5fa0e4b043795ec /src
parent4646f388cb3aa3d3435a08c7bdacab16e9530137 (diff)
downloadmpc-eb4484e39772db743d5ae49e0fe322ef3fcdb9db.tar.gz
renamed mul/div_2exp to mul/div_2ui
git-svn-id: svn://scm.gforge.inria.fr/svn/mpc/trunk@1224 211d60ee-9f03-0410-a15a-8952a2c7a4e4
Diffstat (limited to 'src')
-rw-r--r--src/Makefile.am6
-rw-r--r--src/div_2ui.c (renamed from src/div_2exp.c)6
-rw-r--r--src/mpc.h4
-rw-r--r--src/mul_2ui.c (renamed from src/mul_2exp.c)6
4 files changed, 11 insertions, 11 deletions
diff --git a/src/Makefile.am b/src/Makefile.am
index 5cea5c2..03f7de7 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,6 +1,6 @@
## src/Makefile.am -- Process this file with automake to produce Makefile.in
##
-## Copyright (C) 2008, 2009, 2010, 2011 INRIA
+## Copyright (C) 2008, 2009, 2010, 2011, 2012 INRIA
##
## This file is part of GNU MPC.
##
@@ -21,9 +21,9 @@ lib_LTLIBRARIES = libmpc.la
libmpc_la_LDFLAGS = $(MPC_LDFLAGS) -version-info 2:0:0
libmpc_la_SOURCES = mpc-impl.h abs.c acos.c acosh.c add.c add_fr.c \
add_si.c add_ui.c arg.c asin.c asinh.c atan.c atanh.c clear.c cmp.c \
- cmp_si_si.c conj.c cos.c cosh.c div_2exp.c div.c div_fr.c div_ui.c exp.c \
+ cmp_si_si.c conj.c cos.c cosh.c div_2ui.c div.c div_fr.c div_ui.c exp.c \
fma.c fr_div.c fr_sub.c get_prec2.c get_prec.c get_version.c get_x.c \
- imag.c init2.c init3.c inp_str.c log.c log10.c mem.c mul_2exp.c mul.c \
+ imag.c init2.c init3.c inp_str.c log.c log10.c mem.c mul_2ui.c mul.c \
mul_fr.c mul_i.c mul_si.c mul_ui.c neg.c norm.c out_str.c pow.c pow_fr.c \
pow_ld.c pow_d.c pow_si.c pow_ui.c pow_z.c proj.c real.c urandom.c set.c \
set_prec.c set_str.c set_x.c set_x_x.c sin.c sin_cos.c sinh.c sqr.c \
diff --git a/src/mpc.h b/src/mpc.h
index ddce41e..3f2b56e 100644
--- a/src/mpc.h
+++ b/src/mpc.h
@@ -151,8 +151,8 @@ __MPC_DECLSPEC int mpc_div_fr (mpc_ptr, mpc_srcptr, mpfr_srcptr, mpc_rnd_t);
__MPC_DECLSPEC int mpc_fr_div (mpc_ptr, mpfr_srcptr, mpc_srcptr, mpc_rnd_t);
__MPC_DECLSPEC int mpc_div_ui (mpc_ptr, mpc_srcptr, unsigned long int, mpc_rnd_t);
__MPC_DECLSPEC int mpc_ui_div (mpc_ptr, unsigned long int, mpc_srcptr, mpc_rnd_t);
-__MPC_DECLSPEC int mpc_div_2exp (mpc_ptr, mpc_srcptr, unsigned long int, mpc_rnd_t);
-__MPC_DECLSPEC int mpc_mul_2exp (mpc_ptr, mpc_srcptr, unsigned long int, mpc_rnd_t);
+__MPC_DECLSPEC int mpc_div_2ui (mpc_ptr, mpc_srcptr, unsigned long int, mpc_rnd_t);
+__MPC_DECLSPEC int mpc_mul_2ui (mpc_ptr, mpc_srcptr, unsigned long int, mpc_rnd_t);
__MPC_DECLSPEC int mpc_conj (mpc_ptr, mpc_srcptr, mpc_rnd_t);
__MPC_DECLSPEC int mpc_neg (mpc_ptr, mpc_srcptr, mpc_rnd_t);
__MPC_DECLSPEC int mpc_norm (mpfr_ptr, mpc_srcptr, mpfr_rnd_t);
diff --git a/src/div_2exp.c b/src/div_2ui.c
index 22e67e4..1319930 100644
--- a/src/div_2exp.c
+++ b/src/div_2ui.c
@@ -1,6 +1,6 @@
-/* mpc_div_2exp -- Divide a complex number by 2^e.
+/* mpc_div_2ui -- Divide a complex number by 2^e.
-Copyright (C) 2002, 2009, 2011 INRIA
+Copyright (C) 2002, 2009, 2011, 2012 INRIA
This file is part of GNU MPC.
@@ -21,7 +21,7 @@ along with this program. If not, see http://www.gnu.org/licenses/ .
#include "mpc-impl.h"
int
-mpc_div_2exp (mpc_ptr a, mpc_srcptr b, unsigned long int c, mpc_rnd_t rnd)
+mpc_div_2ui (mpc_ptr a, mpc_srcptr b, unsigned long int c, mpc_rnd_t rnd)
{
int inex_re, inex_im;
diff --git a/src/mul_2exp.c b/src/mul_2ui.c
index ff2efe2..7a6f1ec 100644
--- a/src/mul_2exp.c
+++ b/src/mul_2ui.c
@@ -1,6 +1,6 @@
-/* mpc_mul_2exp -- Multiply a complex number by 2^e.
+/* mpc_mul_2ui -- Multiply a complex number by 2^e.
-Copyright (C) 2002, 2009, 2011 INRIA
+Copyright (C) 2002, 2009, 2011, 2012 INRIA
This file is part of GNU MPC.
@@ -21,7 +21,7 @@ along with this program. If not, see http://www.gnu.org/licenses/ .
#include "mpc-impl.h"
int
-mpc_mul_2exp (mpc_ptr a, mpc_srcptr b, unsigned long int c, mpc_rnd_t rnd)
+mpc_mul_2ui (mpc_ptr a, mpc_srcptr b, unsigned long int c, mpc_rnd_t rnd)
{
int inex_re, inex_im;